@@ -42,5 +42,5 @@ test_that("wm_distribution_ fails well", {
 
   expect_error(wm_distribution_(), "use only one of")
   expect_error(wm_distribution_("asdfafasdfs"), "id must be of class")
-  expect_error(wm_distribution_(44444), "\\(204\\) No Content")
+  expect_warning(wm_distribution_(44444), "\\(204\\) No Content")
 })
